import { List, Modal, Skeleton, Tag } from 'antd';
import 'antd/dist/antd.css';
import React, { useContext, useEffect, useState } from 'react';
import { AnnotationListInfo, EState } from '../../api';
import { userController } from '../../controllers';
import { useUnauthRedirect } from '../../hooks';
import { LoggedUserContext } from '../../contexts/LoggedUserContext';
import {
    CheckCircleOutlined,
    ClockCircleOutlined,
    SyncOutlined,
} from '@ant-design/icons';

interface ModalProps {
    onCancel: () => void;
    userId: string | undefined;
}

function UserDocumentsModal({ onCancel, userId }: ModalProps) {
    const redirecting = useUnauthRedirect('/login');
    const { role } = useContext(LoggedUserContext);
    const [annotations, setAnnotations] = useState<AnnotationListInfo[]>([]);

    const handleOk = () => {
        onCancel();
    };

    const handleCancel = () => {
        onCancel();
    };

    const getStateTag = (state: EState) => {
        let color = 'green';
        let label = 'Hotovo';
        let icon = <CheckCircleOutlined />;
        if (state === EState.New) {
            color = 'volcano';
            label = 'Nový';
            icon = <ClockCircleOutlined />;
        }
        if (state === EState.InProgress) {
            color = 'orange';
            label = 'Rozpracováno';
            icon = <SyncOutlined spin />;
        }
        return (
            <Tag icon={icon} color={color} key={label}>
                {label.toUpperCase()}
            </Tag>
        );
    };

    useEffect(() => {
        if (!redirecting && role === 'ADMINISTRATOR' && userId) {
            userController
                .userUserIdAnnotationsGet(userId)
                .then(({ data: { annotations } }) => {
                    setAnnotations(annotations || []);
                });
        }
    }, [userId, redirecting, role]);

    return (
        <Modal
            title="Dokumenty uživatele"
            onOk={handleOk}
            visible={true}
            onCancel={handleCancel}
            footer={[null]}
        >
            <List
                dataSource={annotations}
                size={'small'}
                grid={{ gutter: 10, column: 1 }}
                style={{ maxHeight: 400, overflowY: 'auto', overflowX: 'hidden' }}
                renderItem={(item) => (
                    <List.Item key={item.annotationId}>
                        <List.Item.Meta
                            title={item.documentName}
                            // @ts-ignore
                            avatar={getStateTag(item.state)}
                        />
                    </List.Item>
                )}
            />
        </Modal>
    );
}

export default UserDocumentsModal;
